@@ -1,8 +1,6 @@
 package Slovo::Controller::Auth;
 use Mojo::Base 'Slovo::Controller', -signatures;
-use feature qw(lexical_subs unicode_strings);
-## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
-no warnings "experimental::lexical_subs";
+
 use Mojo::Util qw(encode sha1_sum);
 
 # Returns the name of the geter for the current user.
