@@ -1,8 +1,5 @@
 package Slovo::Controller::Stranici;
 use Mojo::Base 'Slovo::Controller', -signatures;
-use feature qw(lexical_subs unicode_strings);
-## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
-no warnings "experimental::lexical_subs";
 
 use Role::Tiny::With;
 with 'Slovo::Controller::Role::Stranica';
